import {
  select,
  csv,
  scaleLinear,
  extent,
  axisLeft,
  axisBottom,
  format
} from 'd3';

import { dropDownMenu } from './dropDownMenu';
import { scatterPlot } from './scatterPlot';

const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');

let data;
let xColumn;
let yColumn;

const onXColumnClicked = column => {
  xColumn = column;  
  render();
};

const onYColumnClicked = column => {
  yColumn = column;  
  render();
};

const render = () => {
  
  select('#x-menu')
    .call(dropDownMenu, {
      options: data.columns,
      onOptionClicked: onXColumnClicked,
      selectedOption: xColumn
  });
  
  select('#y-menu')
    .call(dropDownMenu, {
      options: data.columns,
      onOptionClicked: onYColumnClicked,
      selectedOption: yColumn
  });
  
  svg.call(scatterPlot, {
    xValue: d => d[xColumn],
    xAxisLabel: xColumn,
    yValue: d => d[yColumn],
    circleRadius: 8,
    yAxisLabel: yColumn,
    margin: { top: 20, right: 35, bottom: 88, left: 140 },
    width,
    height,
    data
  });
  


};

csv('https://vizhub.com/veagy/datasets/2000-2016 Worldwide Exports.csv')
  .then(loadedData => {
    data = loadedData;
    data.forEach(d => {
      d['China'] = +d['China'];
      d['United States of America'] = +d['United States of America'];
      d['Brazil'] = +d['Brazil'];
      d['India'] = +d['India'];
      d['Japan'] = +d['Japan'];
      d['Mexico'] = +d['Mexico'];
      d['Russian Federation'] = +d['Russian Federation'];
    });
    xColumn = data.columns[4];
    yColumn = data.columns[3];
    render();
});